aboutsummaryrefslogtreecommitdiffstats
path: root/g10/keydb.c
diff options
context:
space:
mode:
authorDavid Shaw <[email protected]>2002-11-25 03:18:48 +0000
committerDavid Shaw <[email protected]>2002-11-25 03:18:48 +0000
commitce4ddd144ccdf6d0beb45cdaf707b2dc0983ccdb (patch)
treebb969574cccd5feeb91c1f6a39507ce6ce1f34f5 /g10/keydb.c
parent* g10.c (add_notation_data): Disallow notation names that do not contain a (diff)
downloadgnupg-ce4ddd144ccdf6d0beb45cdaf707b2dc0983ccdb.tar.gz
gnupg-ce4ddd144ccdf6d0beb45cdaf707b2dc0983ccdb.zip
* g10.c (main), keydb.c (keydb_add_resource, keydb_locate_writable):
Rename --default-keyring as --primary-keyring. Stefan wins the naming contest.
Diffstat (limited to 'g10/keydb.c')
-rw-r--r--g10/keydb.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/g10/keydb.c b/g10/keydb.c
index 7b31e2dd0..3162a1696 100644
--- a/g10/keydb.c
+++ b/g10/keydb.c
@@ -55,7 +55,7 @@ struct resource_item {
static struct resource_item all_resources[MAX_KEYDB_RESOURCES];
static int used_resources;
-static void *default_keyring=NULL;
+static void *primary_keyring=NULL;
struct keydb_handle {
int locked;
@@ -200,7 +200,7 @@ keydb_add_resource (const char *url, int flags, int secret)
else
{
if(flags&2)
- default_keyring=token;
+ primary_keyring=token;
all_resources[used_resources].type = rt;
all_resources[used_resources].u.kr = NULL; /* Not used here */
all_resources[used_resources].token = token;
@@ -211,10 +211,10 @@ keydb_add_resource (const char *url, int flags, int secret)
else
{
/* This keyring was already registered, so ignore it.
- However, we can still mark it as default even if it was
+ However, we can still mark it as primary even if it was
already registered. */
if(flags&2)
- default_keyring=token;
+ primary_keyring=token;
}
break;
@@ -550,12 +550,12 @@ keydb_locate_writable (KEYDB_HANDLE hd, const char *reserved)
if (rc)
return rc;
- /* If we have a default set, try that one first */
- if(default_keyring)
+ /* If we have a primary set, try that one first */
+ if(primary_keyring)
{
for ( ; hd->current >= 0 && hd->current < hd->used; hd->current++)
{
- if(hd->active[hd->current].token==default_keyring)
+ if(hd->active[hd->current].token==primary_keyring)
{
if(keyring_is_writable (hd->active[hd->current].token))
return 0;